#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"              X 1 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 1 X               ",
"              <  X3X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X3X X<               ",
"              O a k h g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g h k g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g k j g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g h f O               ",
"              ; k.7 =.P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.P.=.5 Z.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.s / I.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.K.y.                  ",
"              4 7Xh P.SXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXSXP.f zXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXBXG u.DXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXCX%X@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXxXbXmXmXmXmXmXmXmXmXvXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXxX;Xj.+.#.#.#.#.#.#.=.A.zXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXcX^.S                 ] xXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXxX&Xy.( ` ` ` ' z % - &.xXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXzXxXxXxXxXxXxX,.: u z.xXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX0XG   I @XzXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXH.s   ;.kXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXgXsXdXdXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX@.; a B.vXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXxX#.p h s Q fXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjX5Xv   ) $XxXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXJ       s dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXsXJ.9   r.fXzXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXyX..- p P.mXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXG       p sXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX,Xd    .&XcXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXxX8.G P J #.gXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpXH.: X v.sXzXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXxXcXcXcXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXcX5XX.& a _.bXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXcX#Xt @ +.>XcXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXzXuXV.$ @ G.sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXvX=X'   a @XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXxX0XK.g.J.yXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnXMXnXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              4 7Xh P.SXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXSXP.f zXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXBXG u.DXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXCX%X#                 ",
"              ; k.0 ;.P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.P.;.9 A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.g _ P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.K.u.O                 ",
"              O u # 9 f d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d f 9 # s d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d * 3 f d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d f t .                 ",
"              3 -Xf A.zXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXzXA.s yXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXgXS 0.xXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXjX}.@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.NXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXOX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXnXmXmXmXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXbXmXmXmXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXjX/.K.P.J.}.zXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXzX}.J.P.K./.jXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXd       L cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXL       d dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXh       P cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXh       P cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXd       L cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXL       d dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXjX/.K.P.J.}.zXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXzX}.J.P.K./.jXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXnXmXmXmXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXbXmXmXmXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 3Xh J.BXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXBXJ.d gXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXbXF t.VXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXmX@X@                 ",
"              @ N * z Y P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P Y z * S D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D F , t H D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D G b X                 ",
"              * ,.6                                                                         5 0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.t.t J i.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.y.%.o                 ",
"              4 8Xl                                                                         j xXNXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXVXH i.FXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXZX&X#                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXxXmXMXMXMXMXMXMXMXbXzXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXhX,Xb.p.a.a.a.a.a.s.).yXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXP.5               %.<XcXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q   u D A A A F k.7XxXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q   a.xXdXdXdXdXhXkXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q   f.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXcXcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q   h.VXcXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXbX}.L P P L }.bXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q   n _ Y ) 0.&XhXzXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXJ.        J.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXU.q           6 ~ XXhXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXP.        P.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXP.5   u | >.~ ; o ,.3XcXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXK.        K.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXgX|.{ D k.tXmX;XY $ p _.nXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXnX/.d h h d /.nXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXtXc.; o U.mXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXjXdXdXdXdXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXgXpXpXhXlXzXiXD.:   L.nXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXgXXXl.k.%XxXxXeXd.- $ T.mXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXdXT.z < <.5XxXXXZ # x [.bXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXjX2XF   4 D E m % $ i.9XxXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXjXT.) 5       a >.:XkXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlX Xh.>.%.3.M.6XkXzXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXcXbXmXmXnXbXxXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              4 5Xl                                                                         h jXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXmXG y.ZXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXBX#X@                 ",
"              , T.i                                                                         u }.OXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX@Xb %.&XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX#XS.+                 ",
"              . @ .                                                                         . @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ X o # @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ +                   ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                                ",
"      . O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O .       ",
"    X                                                                                                                                                                                     X     ",
"  X   f 0.-.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.2.>.>.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.2.>.,.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.,.9.p   X   ",
"  X   f C.d.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.9.k.h.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.9.l.g.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.6.Z.N   o   ",
"  X   m p w 8.#.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.9.6 i 8.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.9.3 s 7.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.7.q   @     ",
"  O   r.x.8.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX>.s.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX&.j.UXPXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUXr.  +     ",
"  O   ,.0.$.LXiXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX| 2.KXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX' 7.JXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXuXGX-.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXkXhXhXhXhXhXhXhXkXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXkXvXDXGXFXGXFXFXGXMXkXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXkXxXwX~.U.T.T.T.I.L.>XnXkXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXgXNXY.              6.LXdXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXkXcX5Xm.g.j.x.u.y O b.FXfXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXkXbXGXKXHXUXwX  a #XmXhXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXkXfXfXgXhXi.  _ CXgXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXDXHXJXSXjXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXvXaXj + b.SXfXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXhXZXP u t W SXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXbX@X  d 8XzXjXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX6     t JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXzXcX,.  ' GXfXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX8     u HXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXzXhX6 % L.MXhXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXD 8 6 P DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXcX/.  i jXjXkXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXAXFXFXZXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXjXNX_   @.ZXhXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXgXgXhXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXkXgX7 +  XcXkXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXhXMXs.  w nXkXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXkXvXXXZ.}.xXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXkXVXHXCXkXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   ,.0.$.KXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX| 1.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXIX' 6.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXGX-.  +     ",
"  O   y.l.5.UXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX-.p.UXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX$.h.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXq.  @     ",
"  X   k v f =.| ..............................................| -.a l =.| ..............................................| -.i x =. ...............................................| *.j   X     ",
"  X   N S b i.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.p.l V u.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.p.j Z u.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.y.m   o     ",
"  O   r.k.4.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX=.u.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX@.f.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX0.  @     ",
"  O   ,.0.$.LXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX| 2.LXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXUX] 7.KXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXHX-.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXkXAXGXGXSXkXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXSXGXGXAXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXgXDXY q e H AXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXH e q Y DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXfXJXy     7 FXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX7     y JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXfXJXy     7 FXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX7     y JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXgXDXY q e H AXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXH e q Y DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXkXAXGXGXSXkXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXSXGXGXAXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   ,.9.$.KXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX| 1.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX' 6.HXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXFX-.  +     ",
"  O   y.z.2.UXGXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXFXUX&.p.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX$.h.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXq.  @     ",
"  X   h j m t.<.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.<.y.x f #.] [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ ' $.y l @.] [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ ' +.f   X     ",
"  X   M ~                                                           R a.7.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.6.h.l D f.7.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.6.d.B   o     ",
"  O   7.I.  - + @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ + -   A.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXHXUX@.f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXHXUX0.  @     ",
"  O   *.n.  @                                                   @   h.DXpXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXiXUX] 7.KXpXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXiXHX-.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXhXgXgXgXgXgXhXkXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXxXDXHXHXHXHXJXDXcXkXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXkXzXiXU.V.G.G.G.S.W.yXxXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX=X=           % XXMXhXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX>Xs   l.V.M.v.L.rXxXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXgXgXgXgXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX>Xy   xXKXSXGXDXcXkXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXkXAXFXFXAXkXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX>Xy   gXFXBXvXhXkXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXgXSXH 7 7 H SXgXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX>Xt   m y g 6.yXxXkXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXfXGXe     e GXfXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX:X9     * .   / gXkXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXfXGXq     q GXfXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXcX<Xb # E.VX@X3 o S.SXgXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXgXAXY y y Y AXgXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXcXCXCXxXxXkX2.  q.LXdXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXkXDXJXJXDXkXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXzXsX9XwXlXgXkXt.  7.LXdXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXjXbX&X/ U wXUXfXI   d.JXfXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXkXkXsXj   R h.X.  u -XnXjXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXhXNX.XJ       j T.mXhXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXhXBX7X_.E.^.1XmXkXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXjXbXAXFXDXmXjXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXkXhXhXhXjXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   *.b.  @                                                   @   g.AXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXPX' 6.HXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXFX-.  +     ",
"  O   6.I.  #                                                   #   A.UXHXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXFXUX+.d.UXHXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXFXUX9.  @     ",
"  X   c P   o                                                   o   G 7.-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.-.q.f B 0.-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.-.9.v   X     ",
"    X     o                                                       X                                                                                                                     X       ",
"      X o                                                           o @ + + + + + + + + + + + + + + + + + + + + + + + + + @ X o @ + + + + + + + + + + + + + + + + + + + + + + + + + @ X         ",
"                                                                                                                                                                                                ",
"                                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                ",
"      O @ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +         ",
"    X                                                                                                                                                                   .       ",
"  O   r.XXQ.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.!.(./.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~./.(.!.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.!._.H.  .     ",
"  .   f z N B B B B B B B B B B B B B B B B B B B B B B N C l b V B B B B B B B B B B B B B B B B B B B B B B V b l C N B B B B B B B B B B B B B B B B B B B B B B V p         ",
"  +   R.l rXdXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXtXKXP B.CXpXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXpXCXB.P KXtXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXgX#         ",
"  +   ^.V dXxXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXfXUX~ H.HXjXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXjXHXH.~ UXfXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXvX,   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXjXfXfXfXfXfXdXhXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXkXmXLXPXLXLXLXPXZXjXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXkXvX*Xw.8.9.9.9.4.I.NXjXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXhXBXZ.            T JXfXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXzXsX5X4X2XuXX.  r.AXgXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXxXMXmXnXMXg + :XvXkXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXjXAXHXJXBXjXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXkXfXBXU.O V VXjXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXjXmXE.n.c. XMXjXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXgXDX@.  B.nXkXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXLXs     { UXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXjXvX7Xj X qXvXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXB     &.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXgXSXJ.  ' lXzXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXgXGXU * o 3.KXfXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXkXlXxX%.  E.NXkXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXvXnXnXcXkXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXjXMX3X4 w 5XmXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXkXMXL.  :.bXkXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXxXjX~   T.AXgXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXpXaXjXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXcXcXzXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   E.M yXfXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXKXW A.CXaXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXaXCXA.W KXyXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXhX>   .     ",
"  @   $XD JXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX] ).UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX).] UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<   .     ",
"  X   C 1 E ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! W ] 8 m _ Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! Q _ m 8 ] W ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ +         ",
"  o   6.a Z.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.A.).m ;.W.D.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.D.W.;.m ).A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.*         ",
"  @    XA VXHXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXCXUX_ W.UXSXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXSXUXW._ UXCXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXLX,   .     ",
"  +   Q.N pXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXaXUXQ D.SXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXSXD.Q UXaXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXzX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXxXbXbXvXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXcXbXbXcXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXzXfXwXeXtXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXzXuXeXwXaXzXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXHXM.    < bXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXM     %.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXGXV.  O 5 bXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXZ     =.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXJXx.    o nXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXKXg      .UXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXkXvX0X_.[..XzXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXkXvX$X'._.<XbXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXkXvXAXCXVXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXkXNXZXZXmXkXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXkXjXjXjXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXjXjXjXkXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   Q.N pXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXaXUXQ D.SXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXSXD.Q UXaXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXzX>   .     ",
"  @   .XA nXAXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXmXUX( Q.UXSXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXSXUXW._ UXCXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXLX,   .     ",
"  o   5.s ^.`._._._._._._._._._._._._._._._._._._._._._.^.-XS =.Q.D.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.D.W.;.m ).A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.*         ",
"  X   A =                                                     S ( Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! Q _ m 8 ] W ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ +         ",
"  @   -Xk   @ + + + + + + + + + + + + + + + + + + + + + + &   -XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX).] UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<   .     ",
"  +   ^.s   .                                             +   ^.mXaXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXaXCXA.W KXyXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXhX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXjXhXjXjXjXhXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXzXNXZXZXAXZXAXmXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXzXaX' 3 8 4 6 ; 9.xXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXiXB   v m m j h.xXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXfXfXfXkXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXpXG   gXGXVXSXNXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXzXJXJXKXvXkXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXpXF   jXPXAXvXjXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXcXuXM Z g $XNXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXpXH   I m I T.cXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXbXeX      '.ZXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXiXm   @ 4 X   H.bXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXkXbXwX      _.ZXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXzXsX&.d  XPXI.. g hXxXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXcXaX%.=. .<XmXkXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXxXKXUXcXlXiXm   dXcXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXzXPXPXUXbXkXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXpX)./.lXbXtXc   dXcXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXdXdXdXkXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXkXxXiXK   W.AXB.  m kXxXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXgXCXb.+   .   % ^.nXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXkXNX/.| U  . XnXkXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXjXMXJXPXJXnXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXjXfXdXfXjXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   '.d   .                                             +   ].FXzXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXzXLXJ.~ UXhXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXnX>   .     ",
"      = o                                                     = , > > > > > > > > > > > > > > > > > > > > > > , * + < > > > > > > > > > > > > > > > > > > > > > > > > .         ",
"                                                                                                                                                                                ",
"                                                                . . . . . . . . . . . . . . . . . . . . . . . .     . . . . . . . . . . . . . . . . . . . . . . . . .           ",
"                                                                                                                                                                                ",
"                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                ",
"        . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .         ",
"                                                                                                                                ",
"      X q e e e e e e e e e e e e e e e e e w w e e e e e e e e e e e e e e e e e w e e e e e e e e e e e e e e e e e q .       ",
"      + 2.8.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.7.8.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.6.9.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.7.3.@       ",
"  .   7 ) h.@X`.].].].].].].].].].].].].`.@Xf.| *X).].].].].].].].].].].].].].{.^.L .X`.].].].].].].].].].].].].].).*XL   O     ",
"  .   r e.+XUXVXZXZXZXZXZXZXZXZXZXZXZXZXVXUXXXh.UXMXZXZXZXZXZXZXZXZXZXZXZXZXCXSXvX:.JXVXZXZXZXZXZXZXZXZXZXZXZXZXZXMXUX-.  O     ",
"  .   w 4.`.VXgXjXjXjXjXjXjXjXjXjXjXjXjXgXVX(.y.FXdXjXjXjXjXfXfXfXfXgXjXjXjXjXlXiX#.bXgXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXxXAXFXDXSXVXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXxXsXT.D.H.K.{.xXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXkXvX9XM 8 p   s MXkXlXlXxXpX#.mXjXlXlXlXlXlXhXfXjXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXzXNXNXDXg %.ZXjXlXlXxXpX#.mXjXlXlXlXlXlXSXKXMXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXgXNX].. [.CXhXlXlXxXpX#.mXjXlXlXlXlXxXZ.w.@XMXjXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXhXSX$.y vXlXkXlXlXxXpX#.mXjXlXlXlXkXnX>   w.KXfXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXzXjX6 5.DXhXlXlXlXxXpX#.mXjXlXlXlXkXbXY > Z.SXhXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXhXCX/.o *XMXjXlXlXlXxXpX#.mXjXlXlXlXlXlXbXnXxXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXhXSXL k MXkXkXlXlXlXxXpX#.mXjXlXlXlXlXlXkXkXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXkXxXdX) V.AXhXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXAXMXjXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXhXjXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   w 4.`.VXgXjXjXjXjXjXjXjXjXjXjXjXjXgXVX(.y.FXdXjXjXjXjXjXjXjXjXjXjXjXjXjXlXiX#.bXgXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   r w.+XUXVXZXZXZXZXZXZXZXZXZXZXZXZXVXUXXXg.UXNXZXZXZXZXZXZXZXZXZXZXZXZXZXDXvX-.KXVXZXZXZXZXZXZXZXZXZXZXZXZXZXNXUX*.  O     ",
"  .   5 [ j..X(._._._._._._._._._._._._.(.XXg.+.@X^._._._._._._._._._._._._.).`.Q.W {.(._._._._._._._._._._._._._.^.@XE   o     ",
"      , G @.g.y.u.u.u.u.u.u.u.u.u.u.u.u.y.g.+.I k.r.u.u.u.u.u.u.u.u.u.u.u.u.u.i.w.N s.y.u.u.u.u.u.u.u.u.u.u.u.u.u.r.k.M   X     ",
"  .   t t.&XUXFXHXHXHXHXHXHXHXHXHXHXHXHXFXUX@Xk.UXSXHXHXHXHXHXHXHXHXHXHXHXHXHXLXBX>.UXGXHXHXHXHXHXHXHXHXHXHXHXHXHXSXUX;.  O     ",
"  .   w 3._.MXdXgXgXgXgXgXgXgXgXgXgXgXgXdXNX^.r.SXaXgXgXgXgXgXgXgXgXgXgXgXgXgXjXyX@.cXdXgXgXgXgXgXgXgXgXgXgXgXgXgXaXSXO.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXkXjXjXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXjXjXkXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXkXvXBXmXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXmXBXvXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXkXcXeX#X,XzXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXzX,X#XeXcXkXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXgXHXd.  i nXkXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXnXi   d.HXgXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXgXHXd.  i nXkXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXnXi   d.HXgXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXkXcXeX#X,XzXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXzX,X#XeXcXkXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXkXvXBXmXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXmXBXvXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXkXjXjXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXjXjXkXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].CXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX).u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXfXHX@.  O     ",
"  .   e 6.'.VXhXkXkXkXkXkXkXkXkXkXkXkXkXhXCX(.i.LXjXxXxXxXxXxXxXxXxXxXxXxXxXxXvXdX$.NXlXxXxXxXxXxXxXxXxXxXxXxXxXxXjXLX#.  O     ",
"  .   w 1. XGXvXnXnXnXnXnXnXnXnXnXnXnXnXvXHX{.w.BXyXpXpXpXpXpXpXpXpXpXpXpXpXpXdXqXO.jXiXpXpXpXpXpXpXpXpXpXpXpXpXpXtXBXX.  O     ",
"      - b 5 a u u u u u u u u u u u u u u a 3 B :.@.#.#.#.#.#.#.#.#.#.#.#.#.#.$.O.h &.#.#.#.#.#.#.#.#.#.#.#.#.#.#.+.>.g   X     ",
"  .   e t.                                    k.UXcXmXmXmXmXmXmXmXmXmXmXmXmXmXNXjX&.AXbXmXmXmXmXmXmXmXmXmXmXmXmXmXxXUX%.  O     ",
"  .   q 0.  @ X X X X X X X X X X X X X X @   s.DXdXjXjXjXjXjXjXjXjXjXjXjXjXjXlXiX#.bXhXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXjXgXhXgXhXlXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXNXGXHXJXSXlXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXkXmXg.c m g | hXzXkXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXkXkXlXlXlXlXlXlXxXpX#.mXjXlXlXjXCX~ * c.9.V.jXzXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXzXnXnXzXlXlXlXlXlXxXpX#.mXjXlXlXjXZX) J UXUXLXkXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXjXmX,Xi i ,XmXjXlXlXlXxXpX#.mXjXlXlXjXBX[   w s (.MXjXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXjXBX#X    #XBXjXlXlXlXxXpX#.mXjXlXlXjXNX1.d !.T 4 uXcXkXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXkXvXeXd.d.eXvXkXlXlXlXxXpX#.mXjXlXlXlXkXvXZXIX:X  #XBXjXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXkXcXHXHXcXkXlXlXlXlXxXpX#.mXjXlXlXkXMXq.#.JXm.  3XmXjXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXkXgXgXkXlXlXlXlXlXxXpX#.mXjXlXlXjXBXL.# 7 O ,.mXkXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXBX1XF.[.vXzXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXjXnXFXVXkXlXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXjXhXhXlXlXlXlXlXgXJX@.  O     ",
"  .   q 9.  O                             O   a.AXpXgXgXgXgXgXgXgXgXgXgXgXgXfXjXtX+.xXdXgXgXgXgXgXgXgXgXgXgXgXgXgXpXSXO.  O     ",
"  .   r s.  O                             +   n.UXSXJXJXJXJXJXJXJXJXJXJXJXJXHXLXBX>.UXGXJXJXJXJXJXJXJXJXJXJXJXJXJXSXUX;.  O     ",
"      - b   X                             X   B -.O.@.@.@.@.@.@.@.@.@.@.@.@.@.#.X.g %.+.@.@.@.@.@.@.@.@.@.@.@.@.@.O.;.f   X     ",
"    .     .                                 X                                                                           .       ",
"      . X                                     X O O O O O O O O O O O O O O O O O X O O O O O O O O O O O O O O O O O X         ",
"                                                                                                                                ",
"                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                ",
"      . o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o X         ",
"    .                                                                                           ",
"  .   , D v n n n n n n n n n n n Z b n n n n n n n n n n b Z n n n n n n n n n n n m n X       ",
"  X   s e.K.F.G.G.G.G.G.G.G.G.H.D.1.K.G.G.G.G.G.G.G.G.G.G.K.1.D.H.G.G.G.G.G.G.G.G.D.E...  X     ",
"  o   m H.DXbXMXMXMXMXMXMXMXMXNXxXj.ZXnXMXMXnXbXbXnXMXMXnXZXj.xXNXMXMXMXMXMXMXMXMXcXUX2.  +     ",
"  o   b F.bXfXhXhXhXhXhXhXhXhXkXaXh.xXgXjXhXnXZXVXnXhXhXgXxXh.aXkXhXhXhXhXhXhXhXhXsXSX1.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXkXcX@XP.W.$XzXlXkXbXj.fXzXlXlXlXjXjXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXjXmXc.] m z MXkXkXbXj.fXzXlXlXlXMXmXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXkXMXUX5.>.GXhXkXbXj.fXzXlXlXlX;X1XxXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXlXkXsXf OXBXjXkXbXj.fXzXkXzXxX  u SXhXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXhXAXW.B MXkXlXkXbXj.fXzXlXlXzXu.n.mXkXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXhXDXI w.HXhXlXkXbXj.fXzXlXlXlXFXAXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXzXkXa.5XbXkXlXkXbXj.fXzXlXlXlXgXhXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXlXlXSXcXkXlXlXkXbXj.fXzXlXlXlXlXlXlXlXlXgXGX2.  O     ",
"  o   n H.NXkXzXzXzXzXzXzXzXzXcXgXk.nXlXzXzXzXjXlXxXzXzXlXnXk.gXcXzXzXzXzXzXzXzXzXhXJX3.  O     ",
"  o   b S.xXaXfXfXfXfXfXfXfXfXgXuXf.kXsXfXfXfXfXfXfXfXfXsXkXf.uXgXfXfXfXfXfXfXfXfXiXCX,.  O     ",
"  X   e  .c.h.j.j.j.j.j.j.j.j.k.f.^ z.h.j.j.j.j.j.j.j.j.h.z.^ f.k.j.j.j.j.j.j.j.j.g.N.J   X     ",
"  o   m K.CXxXbXbXbXbXbXbXbXbXnXkXz.NXcXbXbXbXbXbXbXbXbXcXNXz.kXnXbXbXbXbXbXbXbXbXlXPX4.  O     ",
"  o   b G.nXgXkXkXkXkXkXkXkXkXlXsXh.cXjXkXkXkXkXkXkXkXkXjXcXh.sXlXkXkXkXkXkXkXkXkXfXFX1.  O     ",
"  o   n G.MXhXlXlXlXkXkXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXkXkXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXzXbXxXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXvXvXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXzXjXeXsXzXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXyXiXzXlXlXgXGX2.  O     ",
"  o   n G.MXhXjXNX&X  6.HXgXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXzXxX* z AXhXlXgXGX2.  O     ",
"  o   n G.MXhXkXnX6XU L.CXhXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXzXO.8.NXjXlXgXGX2.  O     ",
"  o   n G.MXhXlXkXcXJXNXkXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXFXAXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXkXgXjXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXgXhXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXlXlXlXlXlXgXGX2.  O     ",
"  o   n D.vXdXgXgXgXgXgXgXgXgXjXpXh.vXjXkXkXkXkXkXkXkXkXjXcXh.sXlXkXkXkXkXkXkXkXkXfXFX1.  O     ",
"  o   n T.UXAXDXDXDXDXDXDXDXDXGXVXv.NXvXbXbXbXbXbXbXbXbXcXNXz.kXnXbXbXbXbXbXbXbXbXlXPX4.  O     ",
"  X   u J ( / ( ( ( ( ( ( ( ( ) W L v.h.j.j.j.j.j.j.j.j.h.z.^ f.k.j.j.j.j.j.j.j.j.g.N.J   X     ",
"  o   P i                         W VXpXfXfXfXfXfXfXfXfXsXkXf.uXgXdXfXdXdXdXdXfXfXiXCX,.  O     ",
"  o   I l   + O O O O O O O O #   ) GXjXzXzXzXzXzXzXzXzXlXnXk.gXcXzXzXxXbXnXvXzXzXhXJX3.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXjXyX0XuXlXlXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXzXlXlXlXlXkXbXj.fXzXhXAXk.r F :.vXkXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXxXzXlXlXlXkXbXj.fXzXhXGX3.o.DXcXlXlXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXkXvXyX* O.FXgXlXkXbXj.fXzXhXDX8.@ B k.NXjXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXkXvXiXz 8.AXhXlXkXbXj.fXzXkXbX=X%X-Xt uXcXfXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXzXAXNXkXlXlXkXbXj.fXzXjXBXU.c.`.i aXxXfXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXhXjXlXlXlXkXbXj.fXzXkXnX:XY m K.NXjXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXlXlXlXlXlXkXbXj.fXzXlXkXnXCXMXNXkXlXgXGX2.  O     ",
"  o   P j   X                 O   / CXaXgXgXgXgXgXgXgXgXfXlXg.iXhXgXgXfXdXdXdXgXgXaXAX<.  O     ",
"  o   E x   X                 O   { UXAXGXGXGXGXGXGXGXGXFXPXN.CXJXGXGXGXGXGXGXGXGXAXUXq.  +     ",
"  .   y 4   .                 X   d 0.<.2.2.2.2.2.2.2.2.1.4.J ,.3.2.2.2.2.2.2.2.2.<.q.N   X     ",
"    .     .                     .                                                       .       ",
"      . .                         . O O O O O O O O O O O O X O O O O O O O O O O O + X         ",
"                                                                                                ",
"                                                                                                "
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                        ",
"      . o X o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o X         ",
"    .                                                                                   ",
"  .   > B k z z z z z z z z l v b l z z z z z z z z l b v l z z z z z z z z z x o       ",
"  X   a h.^.E.W.W.W.W.W.W.E.(.n.g.).E.W.W.W.W.W.W.E.).g.n.(.E.W.W.W.W.W.W.R.].>.  X     ",
"  o   x ~.FXbXMXMXMXMXMXMXnXHX%X/.LXbXMXmXbXvXnXMXbXLX/.%XHXnXMXMXMXMXMXMXvXUXs.  O     ",
"  o   l E.bXfXhXhXhXhXhXhXgXmXXXE.BXfXgXbXAXAXNXgXfXBXE.XXmXgXhXhXhXhXhXhXdXSXp.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXgXNXR.] [ v.NXfXCXQ.OXBXjXlXlXjXkXlXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXhXcX2X=X) @.HXdXCXQ.OXBXkXlXzXSXbXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXkXvXHXU .XVXgXCXQ.OXBXhXnX8Xr H.AXhXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXjXBX.XS nXkXhXCXQ.OXBXhXbX9Xd P.ZXhXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXhXhXGXo.0.HXhXjXCXQ.OXBXkXlXxXFXnXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXhXkXvXg.1XnXkXjXCXQ.OXBXjXlXlXhXkXlXlXgXFXa.  O     ",
"  o   l E.mXgXjXjXjXjXjXjXhXMXoXW.VXgXkXjXVXxXhXkXgXVXW.oXMXhXjXjXjXjXjXjXfXDXp.  O     ",
"  o   c ).GXmXBXBXBXBXBXBXMXJX=X_.PXmXBXBXmXNXBXBXmXPX_.=XJXMXBXBXBXBXBXBXnXUXh.  O     ",
"  X   a k.*XXXOXOXOXOXOXOXoX=XS.l.;XXXOXOXOXOXOXOXXX;Xl.S.=XoXOXOXOXOXOXOX.X<X;.  o     ",
"  X   y e.).E.Q.Q.Q.Q.Q.Q.W._.l.r.'.E.Q.Q.Q.Q.Q.Q.E.'.r.l._.W.Q.Q.Q.Q.Q.Q.R.}.o.  o     ",
"  o   c `.KXBXCXCXCXCXCXCXVXPX;X'.UXBXCXCXCXCXCXCXBXUX'.;XPXVXCXCXCXCXCXCXMXUXk.  O     ",
"  X   l R.nXfXjXjXhXhXjXjXgXmXXXE.BXfXjXjXjXjXjXjXfXBXE.XXmXgXjXhXhXhXjXjXdXSXi.  O     ",
"  o   z W.MXhXlXlXzXzXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXxXzXlXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXlXlXlXlXgXFXa.  O     ",
"  o   z W.MXhXjXZXv C SXhXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXhXmX4X  n.DXgXgXFXa.  O     ",
"  o   z W.MXhXkXMXq.y.NXjXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXvXrX] '.BXjXgXFXa.  O     ",
"  o   z W.MXhXlXkXDXSXkXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXkXkXxXJXmXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXhXhXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXgXjXlXlXgXFXa.  O     ",
"  X   l R.bXfXhXhXhXhXhXhXgXmX.XE.BXfXjXjXjXjXjXjXfXBXE.XXmXgXjXjXjXjXjXjXdXSXi.  O     ",
"  o   c '.LXVXZXZXZXZXZXZXCXIX:X'.UXBXCXCXCXCXCXCXBXUX'.;XPXVXCXCXCXCXCXCXMXUXk.  O     ",
"  X   y e.(.R.W.W.W.W.W.W.E.).k.r.'.E.Q.Q.Q.Q.Q.Q.E.'.r.l._.W.Q.Q.Q.Q.Q.Q.R.}.o.  o     ",
"  X   M 6                       k.:X.XOXOXOXOXOXOXXX;Xl.S.=XoXOXoXoXoXOXOX.X<X;.  o     ",
"  o   K f   O o o o o o o o @   ).IXmXBXBXBXBXBXBXmXPX_.=XJXMXBXVXAXSXVXBXnXUXh.  O     ",
"  o   G a   .               o   E.CXgXjXjXhXjXkXjXgXVXW.oXMXhXkXgXqX6XsXkXdXDXp.  O     ",
"  o   G a   .               o   W.ZXhXlXlXmXvXkXlXjXCXQ.OXBXgXZX,.Z ' }.MXdXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlX4XrXxXlXjXCXQ.OXBXfXFX_ 9.gXnXkXgXFXa.  O     ",
"  o   G a   .               o   W.ZXgXxXlX  ] JXgXjXCXQ.OXBXgXAX:.v Z _.BXdXFXa.  O     ",
"  o   G a   .               o   W.ZXhXzXlXn.'.mXjXjXCXQ.OXBXjXcX@XUXk...LXaXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlXDXBXkXlXjXCXQ.OXBXgXCXh.Y A I.CXdXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlXgXjXlXlXjXCXQ.OXBXjXzXlXW.|.mXkXgXFXa.  O     ",
"  X   F a   .               o   T.NXsXgXgXgXgXgXgXdXMXR..XnXfXgXgXBXnXfXgXaXZXi.  O     ",
"  o   P f   .               o   [.UXAXFXFXFXFXFXFXSXUX}.<XUXDXFXFXSXSXFXFXZXUXx.  O     ",
"  .   i 4   .               X   o.k.i.a.a.a.a.a.a.i.k.o.;.h.p.a.a.a.a.a.a.i.x.T   X     ",
"    .     .                   .                                                 .       ",
"      . .                       o O O O O O O O O O O o o O O O O O O O O O O X         ",
"                                                                                        ",
"                                                                                        "
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                ",
"  . ; & & & & & & & & : & & & & & & & & : * & & & & & & & - o   ",
"  $ 4.F.C.Z.Z.Z.Z.C.A.e.V.Z.Z.V.V.C.C.D.t.n.A.Z.Z.Z.Z.V.H.0.    ",
"  & S.SXbXmXmXmXmXnXVXE.cXMXMXHXHXVXbXDX^.pXVXmXmXmXmXvXLXE.  o ",
"  & C.bXgXjXjXjXjXhXxXY.dXlXfX'.`.qXkXbXQ.wXxXjXhXgXjXfXCXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.fXcXpXF.K b.AXbXQ.eXvXjXMXZXkXhXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXzXkXUX-.;XnXmXQ.eXzXSXv.[ ZXfXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXlXNXoX} CXgXMXQ.eXxXNX_.v.MXgXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXjXAXC.J.AXgXMXQ.eXvXjXBXDXkXhXAXY.  o ",
"  & C.nXhXkXkXkXkXjXcXY.fXlXkXjXxXkXhXmXQ.wXcXkXhXgXkXgXZXY.  o ",
"  & S.VXxXcXcXcXcXcXmXE.kXbXcXvXcXvXxXCX^.yXmXcXcXcXcXlXFXE.  o ",
"  # >.!.U.T.T.T.T.Y.E.8.I.T.T.T.T.T.U.~.q.D.E.Y.T.T.T.U.(.8.  X ",
"  & B.cXdXgXgXgXgXfXkXI.aXhXgXgXgXgXdXvXR.9XkXfXgXgXgXsXNXP.  o ",
"  & Z.MXkXzXjXkXzXlXbXT.hXxXzXzXzXzXkXNX!.rXbXzXkXjXzXjXSXT.  o ",
"  & Z.mXjXjXDXBXjXkXcXT.gXzXlXlXlXlXjXMXQ.eXvXjXBXDXjXhXAXY.  o ",
"  & Z.mXgXVX3.J.ZXhXcXT.gXzXlXlXlXlXjXMXQ.eXzXCXJ.3.VXfXAXY.  o ",
"  & Z.mXgXVX3.J.ZXhXcXT.gXzXlXlXlXlXjXMXQ.eXzXCXJ.3.VXfXAXY.  o ",
"  & Z.mXjXkXDXBXjXkXcXT.gXzXlXlXlXlXjXMXQ.eXvXjXBXDXkXhXAXY.  o ",
"  & V.cXdXgXsXdXhXfXkXU.dXkXjXjXjXjXgXnXW.qXxXjXgXfXjXfXCXU.  o ",
"  & L.UXSXFXFXFXFXDXKX(.cXNXMXMXMXMXnXDX).sXCXMXMXMXMXbXLX!.  o ",
"  & o.g.s.d.d.d.d.d.s.-.Q.!.Q.Q.Q.Q.W.).t.K.^.Q.Q.Q.Q.E.].q.  X ",
"  8 f                 N jX0XeXeXeXeXqXsXK.,XuXeXrXyXrX0XjXD.  o ",
"  9 M   @ O O O O #   P DXzXvXzXzXvXxXCX^.uXmXvXcXyXjXxXFXE.  o ",
"  9 n   X         o   J CXhXjXCXCXjXjXMXQ.eXvXlX#.1.XXvXCXY.  o ",
"  9 n   X         o   J ZXfXBXJ.J.BXgXMXQ.eXvXkXZ y.uXlXZXY.  o ",
"  9 n   X         o   J ZXdXDX3.3.DXfXMXQ.eXvXhXE.d.>.ZXBXY.  o ",
"  9 n   X         o   J ZXjXjXVXVXkXjXMXQ.eXcXxXc.@.z.BXVXY.  o ",
"  8 b   X         o   H NXdXhXfXfXhXfXbXE.0XlXlX4X`.kXdXBXI.  o ",
"  0 N   X         o   I UXVXAXAXAXAXCXLX].jXGXCXGXUXZXBXUX(.  o ",
"  1 p   .         X   z /.I.Y.Y.Y.Y.U.!.q.D.E.Y.Y.U.Y.I.(.7.  X ",
"      .             .                                       .   ",
"    .                 . o o o o o o o o X o o o o o o o o X     "
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"o 1 > > > > > > 2 > > > > > > 2 , > > > > > < + ",
": b. X_.'.'.'.`.m.'.`.[.]._.}.B.Q.[.`.`._. XA.O ",
"> |.HXmXNXNXNXNX|.BXBXkXbXNXDX+XfXZXMXmXmXHX-X  ",
"> _.mXgXjXjXjXhX_.jXkXL.[ :XVX[.eXlXxXMXfXmX+X  ",
"> '.NXjXlXlXlXlX'.lXlXbX4.uXNX|.eXAX|.>.NXMX@X  ",
"> '.NXjXlXlXlXlX'.jXCX/.f.SXcX|.rXmX0X|.xXNX#X  ",
"> '.NXjXlXlXlXlX'.kXbX>X8XcXnX|.tXcXvXBXhXBX#X  ",
"> `.NXhXlXlXlXkX`.lXjXbXcXhXnX|.rXcXkXjXjXNX@X  ",
"- k..X_.'.'.'.`.k.'.'.`.`.`.|.c.W.[.'.'._..XN.  ",
"> '.BXkXjXkXzXlX'.zXlXlXlXkXmX|.tXvXkXjXkXBX#X  ",
"> `.NXgXSXnXkXlX'.lXlXlXlXjXmX|.tXxXbXSXhXBX@X  ",
"> `.MXbXv.=XMXjX'.lXlXlXlXjXmX|.rXVX=Xv.nXMX@X  ",
"> `.MXbXv.=XMXjX'.lXlXlXlXjXmX|.rXVX=Xv.nXMX@X  ",
"> ).nXsXCXxXfXgX_.kXjXjXjXhXbX}.rXlXvXAXfXMX+X  ",
"> OXUXAXZXSXDXDXXXmXmXmXmXbXAXOXsXBXbXvXbXDX=X  ",
"> 6.B.v.b.b.n.x.y.XX}.|.|.}.OXm.^.XX{.[.{.#XZ.  ",
"r 3             ^ cXqXrXrXrXsX^.3XuXdXlXyXfX[.  ",
"t u   + O O #   X.JXjXVXVXlXBXXXuXCX-XP.wXFX$X  ",
"t r   .     O   | SXxX=X=XvXbX|.qXHX,.&.aXVX@X  ",
"t r   .     O   | ZXVXv.v.AXvX|.eXBX`.5.H.PXOX  ",
"r r   .     O   } AXsXnXnXfXbX{.qXMX X:.}.DXoX  ",
"y y   .     O   o.UXnXMXMXMXDX@XgXZXNXvXZXGX:X  ",
"9 9   .     o   E 2XoX@X@X+X=XA.[.%X@X#XOX:XJ.  ",
"                                                "
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
". @ + + + # @ + O @ # + + + @ . ",
"+ V.@X{.XXU._.XX@X[.P..X|.#XA.. ",
"+ @XJXnXSX7XvX7X!.NX3XZXlXHX=X  ",
"+ {.nXdXzX;XsX,XZ.xX%XxXH.lXoX  ",
"+ oXAXzXNX3XjXrXyXvX,XMXvXSX$X  ",
"+ P.8X-X4X`.$X5X4X-X(.2X-X8XT.  ",
"+ ).lXfXdX%X8XpXiXeX+XaXgXlX].  ",
"+ XXMXoXMX2XaXbXcXjX>XmXoXMX#X  ",
"+ }.cX}.cX>XpXcXxXgX:XbXXXmX@X  ",
"O #XPXFXFX7XwXjXgXpX&XjXkXbX X  ",
"= J K J F / =X:X:X&X~.<X2X5XI.  ",
"1 ;       w bXvXbXjX<XzXE.bX%X  ",
"< 6   @   s mX.X.XzX-XaX%.>X%X  ",
"1 6   o   d CXnXmXnX4XSX(.pX<X  ",
": 1   X   r +X+X@X XI.#X$X,XS.  ",
"                                "
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
